==> certmanager-model-v1alpha3-6.3.0-sources.jar: io/fabric8/certmanager/api/model/v1alpha3/VenafiIssuerFluentImpl.java <==
package io.fabric8.certmanager.api.model.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class VenafiIssuerFluentImpl<A extends VenafiIssuerFluent<A>> extends BaseFluent<A> implements VenafiIssuerFluent<A>{
  public VenafiIssuerFluentImpl() {
  }
  public VenafiIssuerFluentImpl(VenafiIssuer instance) {
    this.withCloud(instance.getCloud()); 
    this.withTpp(instance.getTpp()); 
    this.withZone(instance.getZone()); 
  }
  private VenafiCloudBuilder cloud;
  private VenafiTPPBuilder tpp;
  private String zone;
  
  /**
   * This method has been deprecated, please use method buildCloud instead.
   * @return The buildable object.
   */
  @Deprecated
  public VenafiCloud getCloud() {
    return this.cloud!=null ?this.cloud.build():null;
  }
  public VenafiCloud buildCloud() {
    return this.cloud!=null ?this.cloud.build():null;
  }
  public A withCloud(VenafiCloud cloud) {
    _visitables.get("cloud").remove(this.cloud);
    if (cloud!=null){ this.cloud= new VenafiCloudBuilder(cloud); _visitables.get("cloud").add(this.cloud);} else { this.cloud = null; _visitables.get("cloud").remove(this.cloud); } return (A) this;
  }
  public Boolean hasCloud() {
    return this.cloud != null;
  }
  public VenafiIssuerFluent.CloudNested<A> withNewCloud() {
    return new VenafiIssuerFluentImpl.CloudNestedImpl();
  }
  public VenafiIssuerFluent.CloudNested<A> withNewCloudLike(VenafiCloud item) {
    return new VenafiIssuerFluentImpl.CloudNestedImpl(item);
  }
  public VenafiIssuerFluent.CloudNested<A> editCloud() {
    return withNewCloudLike(getCloud());
  }
  public VenafiIssuerFluent.CloudNested<A> editOrNewCloud() {
    return withNewCloudLike(getCloud() != null ? getCloud(): new VenafiCloudBuilder().build());
  }
  public VenafiIssuerFluent.CloudNested<A> editOrNewCloudLike(VenafiCloud item) {
    return withNewCloudLike(getCloud() != null ? getCloud(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildTpp instead.
   * @return The buildable object.
   */
  @Deprecated
  public VenafiTPP getTpp() {
    return this.tpp!=null ?this.tpp.build():null;
  }
  public VenafiTPP buildTpp() {
    return this.tpp!=null ?this.tpp.build():null;
  }
  public A withTpp(VenafiTPP tpp) {
    _visitables.get("tpp").remove(this.tpp);
    if (tpp!=null){ this.tpp= new VenafiTPPBuilder(tpp); _visitables.get("tpp").add(this.tpp);} else { this.tpp = null; _visitables.get("tpp").remove(this.tpp); } return (A) this;
  }
  public Boolean hasTpp() {
    return this.tpp != null;
  }
  public VenafiIssuerFluent.TppNested<A> withNewTpp() {
    return new VenafiIssuerFluentImpl.TppNestedImpl();
  }
  public VenafiIssuerFluent.TppNested<A> withNewTppLike(VenafiTPP item) {
    return new VenafiIssuerFluentImpl.TppNestedImpl(item);
  }
  public VenafiIssuerFluent.TppNested<A> editTpp() {
    return withNewTppLike(getTpp());
  }
  public VenafiIssuerFluent.TppNested<A> editOrNewTpp() {
    return withNewTppLike(getTpp() != null ? getTpp(): new VenafiTPPBuilder().build());
  }
  public VenafiIssuerFluent.TppNested<A> editOrNewTppLike(VenafiTPP item) {
    return withNewTppLike(getTpp() != null ? getTpp(): item);
  }
  public String getZone() {
    return this.zone;
  }
  public A withZone(String zone) {
    this.zone=zone; return (A) this;
  }
  public Boolean hasZone() {
    return this.zone != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    VenafiIssuerFluentImpl that = (VenafiIssuerFluentImpl) o;
    if (cloud != null ? !cloud.equals(that.cloud) :that.cloud != null) return false;
    if (tpp != null ? !tpp.equals(that.tpp) :that.tpp != null) return false;
    if (zone != null ? !zone.equals(that.zone) :that.zone != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(cloud,  tpp,  zone,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (cloud != null) { sb.append("cloud:"); sb.append(cloud + ","); }
    if (tpp != null) { sb.append("tpp:"); sb.append(tpp + ","); }
    if (zone != null) { sb.append("zone:"); sb.append(zone); }
    sb.append("}");
    return sb.toString();
  }
  class CloudNestedImpl<N> extends VenafiCloudFluentImpl<VenafiIssuerFluent.CloudNested<N>> implements VenafiIssuerFluent.CloudNested<N>,Nested<N>{
    CloudNestedImpl(VenafiCloud item) {
      this.builder = new VenafiCloudBuilder(this, item);
    }
    CloudNestedImpl() {
      this.builder = new VenafiCloudBuilder(this);
    }
    VenafiCloudBuilder builder;
    public N and() {
      return (N) VenafiIssuerFluentImpl.this.withCloud(builder.build());
    }
    public N endCloud() {
      return and();
    }
    
  }
  class TppNestedImpl<N> extends VenafiTPPFluentImpl<VenafiIssuerFluent.TppNested<N>> implements VenafiIssuerFluent.TppNested<N>,Nested<N>{
    TppNestedImpl(VenafiTPP item) {
      this.builder = new VenafiTPPBuilder(this, item);
    }
    TppNestedImpl() {
      this.builder = new VenafiTPPBuilder(this);
    }
    VenafiTPPBuilder builder;
    public N and() {
      return (N) VenafiIssuerFluentImpl.this.withTpp(builder.build());
    }
    public N endTpp() {
      return and();
    }
    
  }
  
}

==> certmanager-model-v1alpha3-6.7.2-sources.jar: io/fabric8/certmanager/api/model/v1alpha3/VenafiIssuerFluentImpl.java <==
package io.fabric8.certmanager.api.model.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class VenafiIssuerFluentImpl<A extends VenafiIssuerFluent<A>> extends BaseFluent<A> implements VenafiIssuerFluent<A>{
  public VenafiIssuerFluentImpl() {
  }
  public VenafiIssuerFluentImpl(VenafiIssuer instance) {
    if (instance != null) {
      this.withCloud(instance.getCloud());
      this.withTpp(instance.getTpp());
      this.withZone(instance.getZone());
    }
  }
  private VenafiCloudBuilder cloud;
  private VenafiTPPBuilder tpp;
  private String zone;
  
  /**
   * This method has been deprecated, please use method buildCloud instead.
   * @return The buildable object.
   */
  @Deprecated
  public VenafiCloud getCloud() {
    return this.cloud!=null ?this.cloud.build():null;
  }
  public VenafiCloud buildCloud() {
    return this.cloud!=null ?this.cloud.build():null;
  }
  public A withCloud(VenafiCloud cloud) {
    _visitables.get("cloud").remove(this.cloud);
    if (cloud!=null){ this.cloud= new VenafiCloudBuilder(cloud); _visitables.get("cloud").add(this.cloud);} else { this.cloud = null; _visitables.get("cloud").remove(this.cloud); } return (A) this;
  }
  public Boolean hasCloud() {
    return this.cloud != null;
  }
  public VenafiIssuerFluentImpl.CloudNested<A> withNewCloud() {
    return new VenafiIssuerFluentImpl.CloudNestedImpl();
  }
  public VenafiIssuerFluentImpl.CloudNested<A> withNewCloudLike(VenafiCloud item) {
    return new VenafiIssuerFluentImpl.CloudNestedImpl(item);
  }
  public VenafiIssuerFluentImpl.CloudNested<A> editCloud() {
    return withNewCloudLike(getCloud());
  }
  public VenafiIssuerFluentImpl.CloudNested<A> editOrNewCloud() {
    return withNewCloudLike(getCloud() != null ? getCloud(): new VenafiCloudBuilder().build());
  }
  public VenafiIssuerFluentImpl.CloudNested<A> editOrNewCloudLike(VenafiCloud item) {
    return withNewCloudLike(getCloud() != null ? getCloud(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildTpp instead.
   * @return The buildable object.
   */
  @Deprecated
  public VenafiTPP getTpp() {
    return this.tpp!=null ?this.tpp.build():null;
  }
  public VenafiTPP buildTpp() {
    return this.tpp!=null ?this.tpp.build():null;
  }
  public A withTpp(VenafiTPP tpp) {
    _visitables.get("tpp").remove(this.tpp);
    if (tpp!=null){ this.tpp= new VenafiTPPBuilder(tpp); _visitables.get("tpp").add(this.tpp);} else { this.tpp = null; _visitables.get("tpp").remove(this.tpp); } return (A) this;
  }
  public Boolean hasTpp() {
    return this.tpp != null;
  }
  public VenafiIssuerFluentImpl.TppNested<A> withNewTpp() {
    return new VenafiIssuerFluentImpl.TppNestedImpl();
  }
  public VenafiIssuerFluentImpl.TppNested<A> withNewTppLike(VenafiTPP item) {
    return new VenafiIssuerFluentImpl.TppNestedImpl(item);
  }
  public VenafiIssuerFluentImpl.TppNested<A> editTpp() {
    return withNewTppLike(getTpp());
  }
  public VenafiIssuerFluentImpl.TppNested<A> editOrNewTpp() {
    return withNewTppLike(getTpp() != null ? getTpp(): new VenafiTPPBuilder().build());
  }
  public VenafiIssuerFluentImpl.TppNested<A> editOrNewTppLike(VenafiTPP item) {
    return withNewTppLike(getTpp() != null ? getTpp(): item);
  }
  public String getZone() {
    return this.zone;
  }
  public A withZone(String zone) {
    this.zone=zone; return (A) this;
  }
  public Boolean hasZone() {
    return this.zone != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    VenafiIssuerFluentImpl that = (VenafiIssuerFluentImpl) o;
    if (!java.util.Objects.equals(cloud, that.cloud)) return false;

    if (!java.util.Objects.equals(tpp, that.tpp)) return false;

    if (!java.util.Objects.equals(zone, that.zone)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(cloud,  tpp,  zone,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (cloud != null) { sb.append("cloud:"); sb.append(cloud + ","); }
    if (tpp != null) { sb.append("tpp:"); sb.append(tpp + ","); }
    if (zone != null) { sb.append("zone:"); sb.append(zone); }
    sb.append("}");
    return sb.toString();
  }
  class CloudNestedImpl<N> extends VenafiCloudFluentImpl<VenafiIssuerFluentImpl.CloudNested<N>> implements VenafiIssuerFluentImpl.CloudNested<N>,Nested<N>{
    CloudNestedImpl(VenafiCloud item) {
      this.builder = new VenafiCloudBuilder(this, item);
    }
    CloudNestedImpl() {
      this.builder = new VenafiCloudBuilder(this);
    }
    VenafiCloudBuilder builder;
    public N and() {
      return (N) VenafiIssuerFluentImpl.this.withCloud(builder.build());
    }
    public N endCloud() {
      return and();
    }
    
  }
  class TppNestedImpl<N> extends VenafiTPPFluentImpl<VenafiIssuerFluentImpl.TppNested<N>> implements VenafiIssuerFluentImpl.TppNested<N>,Nested<N>{
    TppNestedImpl(VenafiTPP item) {
      this.builder = new VenafiTPPBuilder(this, item);
    }
    TppNestedImpl() {
      this.builder = new VenafiTPPBuilder(this);
    }
    VenafiTPPBuilder builder;
    public N and() {
      return (N) VenafiIssuerFluentImpl.this.withTpp(builder.build());
    }
    public N endTpp() {
      return and();
    }
    
  }
  
}
